/*
 * Copyright 2008-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.glassfish.auth;

import java.util.List;

/**
 * Interface for the authentication data (user, groups. password, seed). 
 * 
 * @author Erik Brakkee
 */
public interface AuthenticationRepository {

    /**
     * Finds the password for a given user. 
     * @param aUsername Username. 
     * @return Password or null if the user is not found. 
     */
    String findPassword(String aUsername);
    
    /**
     * FInds the groups a user belongs to. 
     * @param aUsername User. 
     * @return Groups. Always non-null. Will return empty array for unknown user.  
     */
    List<String> findGroups(String aUsername);
    
    /**
     * Finds a seed for a given username based on the configured sql seed query.
     * 
     * @param aUsername
     *            Username.
     * @return The seed found or the empty string if no seeds or multiple seeds
     *         were found of if the user is unknown.
     */
    String findSeed(String aUsername);
}
