/*
 * Copyright 2008-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.glassfish.auth.cache.impl;

/**
 * MBean interface for {@link SimpleExpiryCache}. 
 * 
 * @author Erik Brakkee
 */
public interface SimpleExpiryCacheManagementMBean {
    
    /**
     * Gets the number of entries, including expired ones.
     * @return Size.
     */
    int size(); 
    
    
    /**
     * Gest the expiry time in seconds. 
     * @return Expiry time. 
     */
    int getExpiryTimeSeconds();
    
    /**
     * Gets the list of cached users.. 
     * @return Users
     */
    String[] users();
    
    /**
     * Clears the expired entries from the cache.
     */
    void clearExpired();
    
    /**
     * Clears all entries from the cache. 
     */
    void clearAll();
    
    /**
     * Clears the entries for a specific user from the cache. 
     * @param aUsername
     */
    void clearUser(String aUsername);
    
}
